@@ -2,11 +2,8 @@
 Classes that represent alignments between multiple sequences.
 """
 import random
-import string
 import weakref
 
-import six
-
 from bx.misc.readlengths import read_lengths_file
 
 # DNA reverse complement table
@@ -15,15 +12,12 @@ from bx.misc.readlengths import read_lengths_file
 #            "                                                                " \
 #            "                                                                "
 
-if six.PY2:
-    DNA_COMP = string.maketrans("ACGTacgt", "TGCAtgca")
-else:
-    DNA_COMP = str.maketrans("ACGTacgt", "TGCAtgca")
+DNA_COMP = str.maketrans("ACGTacgt", "TGCAtgca")
 
 
-class Alignment(object):
+class Alignment:
 
-    def __init__(self, score=0, attributes={}, species_to_lengths=None):
+    def __init__(self, score=0, attributes=None, species_to_lengths=None):
         # species_to_lengths is needed only for file formats that don't provide
         # chromosome lengths;  it maps each species name to one of these:
         #   - the name of a file that contains a list of chromosome length pairs
@@ -31,6 +25,8 @@ class Alignment(object):
         #   - a single length value (useful when we just have one sequence and no chromosomes)
         # internally a file name is replaced by a dict, but only on an "as
         # needed" basis
+        if attributes is None:
+            attributes = {}
         self.score = score
         self.text_size = 0
         self.attributes = attributes
@@ -67,7 +63,7 @@ class Alignment(object):
     def __str__(self):
         s = "a score=" + str(self.score)
         for key in self.attributes:
-            s += " %s=%s" % (key, self.attributes[key])
+            s += f" {key}={self.attributes[key]}"
         s += "\n"
         # Components
         for c in self.components:
@@ -89,7 +85,7 @@ class Alignment(object):
             chrom_to_length = read_lengths_file(chrom_to_length)
             self.species_to_lengths[species] = chrom_to_length
         if chrom not in chrom_to_length:
-            raise ValueError("no src_size (%s has no length for %s)" % (species, chrom))
+            raise ValueError(f"no src_size ({species} has no length for {chrom})")
         return chrom_to_length[chrom]
 
     def get_component_by_src(self, src):
@@ -112,9 +108,6 @@ class Alignment(object):
     def slice(self, start, end):
         new = Alignment(score=self.score, attributes=self.attributes)
         for component in self.components:
-            # FIXME: Is this the right solution?
-            if component.empty:
-                continue
             new.components.append(component.slice(start, end))
         new.text_size = end - start
         return new
@@ -153,8 +146,11 @@ class Alignment(object):
         return self.slice(start_col, end_col)
 
     def column_iter(self):
+        # FIXME: The empty component are not present
+        # in column_iter.
+        # Maybe it would be good to use - and =
         for i in range(self.text_size):
-            yield [c.text[i] for c in self.components]
+            yield [c.text[i] for c in self.components if not c.empty]
 
     def limit_to_species(self, species):
         new = Alignment(score=self.score, attributes=self.attributes)
@@ -171,6 +167,8 @@ class Alignment(object):
         """
         seqs = []
         for c in self.components:
+            if c.empty:
+                seqs.append(None)
             try:
                 seqs.append(list(c.text))
             except TypeError:
@@ -223,7 +221,7 @@ class Alignment(object):
         return new
 
 
-class Component(object):
+class Component:
 
     def __init__(self, src='', start=0, size=0, strand=None, src_size=None, text=''):
         self._alignment = None
@@ -240,7 +238,7 @@ class Component(object):
         self.synteny_right = None
         self.synteny_empty = None
         # If true, this component actually represents a non-aligning region,
-        # and has no text.
+        # and text is None.
         self.empty = False
         # Index maps a coordinate (distance along + strand from + start) to alignment column
         self.index = None
@@ -293,16 +291,33 @@ class Component(object):
             strand = "-"
         else:
             strand = "+"
-        comp = [ch for ch in self.text.translate(DNA_COMP)]
-        comp.reverse()
-        text = "".join(comp)
+        if self.empty:
+            text = None
+        else:
+            comp = [ch for ch in self.text.translate(DNA_COMP)]
+            comp.reverse()
+            text = "".join(comp)
         new = Component(self.src, start, self.size, strand, self._src_size, text)
+        if self.empty:
+            new.empty = True
+            new.synteny_empty = self.synteny_empty
+        # Propagate supplementary info
+        if self.synteny_left:
+            new.synteny_right = self.synteny_left
+        if self.synteny_right:
+            new.synteny_left = self.synteny_right
         new._alignment = self._alignment
         return new
 
     def slice(self, start, end):
         new = Component(src=self.src, start=self.start, strand=self.strand, src_size=self._src_size)
         new._alignment = self._alignment
+        if self.empty:
+            new.empty = True
+            new.size = self.size
+            new.text = None
+            new.synteny_empty = self.synteny_empty
+            return new
         new.text = self.text[start:end]
 
         # for i in range( 0, start ):
@@ -316,8 +331,14 @@ class Component(object):
         # one of the ends changes. In general the 'i' rows of a MAF only
         # make sense in context (relative to the previous and next alignments
         # in a stream, slicing breaks that).
-        new.synteny_left = self.synteny_left
-        new.synteny_right = self.synteny_right
+        # LD: Indeed, I think it is wrong to keep them. Let's keep the info
+        # only when the boundaries are kept.
+        if self.synteny_left:
+            if start == 0:
+                new.synteny_left = self.synteny_left
+        if self.synteny_right:
+            if end == len(self.text):
+                new.synteny_right = self.synteny_right
 
         return new
 
@@ -341,6 +362,8 @@ class Component(object):
         pos is relative to the + strand, regardless of the component's strand.
 
         """
+        if self.empty:
+            raise ValueError("There is no column index. It is empty.")
         start, end = self.get_forward_strand_start(), self.get_forward_strand_end()
         if pos < start or pos > end:
             raise ValueError("Range error: %d not in %d-%d" % (pos, start, end))
@@ -410,10 +433,12 @@ def get_reader(format, infile, species_to_lengths=None):
         raise ValueError("Unknown alignment format %s" % format)
 
 
-def get_writer(format, outfile, attributes={}):
+def get_writer(format, outfile, attributes=None):
     import bx.align.axt
     import bx.align.lav
     import bx.align.maf
+    if attributes is None:
+        attributes = {}
     if format == "maf":
         return bx.align.maf.Writer(outfile, attributes)
     elif format == "axt":
@@ -440,10 +465,11 @@ def get_indexed(format, filename, index_filename=None, keep_open=False, species_
 
 def shuffle_columns(a):
     """Randomize the columns of an alignment"""
-    mask = range(a.text_size)
+    mask = list(range(a.text_size))
     random.shuffle(mask)
     for c in a.components:
-        c.text = ''.join([c.text[i] for i in mask])
+        if not c.empty:
+            c.text = ''.join([c.text[i] for i in mask])
 
 
 def src_split(src):  # splits src into species,chrom
