@@ -8,8 +8,6 @@ pseudo-random acccess.
 read only access to an on disk binned array.
 """
 
-from __future__ import division
-
 import math
 import sys
 from struct import (
@@ -21,12 +19,11 @@ from struct import (
 from numpy import (
     array,
     concatenate,
-    fromstring,
+    frombuffer,
     NaN,
     resize,
     zeros
 )
-from six import binary_type
 
 from bx_extras.lrucache import LRUCache
 
@@ -46,9 +43,9 @@ VERSION = 2
 
 # Compression types
 
-comp_types = dict()
-
-comp_types['none'] = (lambda x: x, lambda x: x)
+comp_types = {
+    'none': (lambda x: x, lambda x: x)
+}
 
 try:
     import zlib
@@ -66,17 +63,17 @@ MAX = 512*1024*1024
 
 
 def bytesify(s):
-    if isinstance(s, binary_type):
+    if isinstance(s, bytes):
         return s
     else:
         return s.encode()
 
 
-class BinnedArray(object):
+class BinnedArray:
     def __init__(self, bin_size=512*1024, default=NaN, max_size=MAX, typecode="f"):
         self.max_size = max_size
         self.bin_size = bin_size
-        self.nbins = int(math.ceil((max_size / self.bin_size)))
+        self.nbins = int(math.ceil(max_size / self.bin_size))
         self.bins = [None] * self.nbins
         self.default = default
         self.typecode = typecode
@@ -153,7 +150,7 @@ class BinnedArray(object):
         # around that by byteswapping the array
         if platform_is_little_endian:
             a = a.byteswap()
-        f.write(a.tostring())
+        f.write(a.tobytes())
         # Save current position (start of bin offsets)
         index_start_pos = f.tell()
         # Skip forward to save space for index
@@ -166,9 +163,9 @@ class BinnedArray(object):
             else:
                 assert bin.dtype.char == self.typecode
                 if platform_is_little_endian:
-                    s = bin.byteswap().tostring()
+                    s = bin.byteswap().tobytes()
                 else:
-                    s = bin.tostring()
+                    s = bin.tobytes()
                 compressed = compress(s)
                 bin_pos_and_size.append((f.tell(), len(compressed)))
                 f.write(compressed)
@@ -178,7 +175,7 @@ class BinnedArray(object):
             write_packed(f, ">2I", pos, size)
 
 
-class FileBinnedArray(object):
+class FileBinnedArray:
     def __init__(self, f, cache=32):
         # If cache=None, then everything is allowed to stay in memory,
         # this is the default behavior.
@@ -204,14 +201,14 @@ class FileBinnedArray(object):
         self.decompress = comp_types[self.comp_type][1]
         # Read default value
         s = f.read(calcsize(self.typecode))
-        a = fromstring(s, self.typecode)
+        a = frombuffer(s, self.typecode)
         if platform_is_little_endian:
             a = a.byteswap()
         self.default = a[0]
         # Read bin sizes and offsets
         self.bin_pos = []
         self.bin_sizes = []
-        for i in range(nbins):
+        for _ in range(nbins):
             pos, size = read_packed(f, ">2I")
             self.bin_pos.append(pos)
             self.bin_sizes.append(size)
@@ -223,7 +220,7 @@ class FileBinnedArray(object):
         assert self.bin_pos[index] != 0
         self.f.seek(self.bin_pos[index])
         raw = self.f.read(self.bin_sizes[index])
-        a = fromstring(self.decompress(raw), self.typecode)
+        a = frombuffer(self.decompress(raw), self.typecode)
         if platform_is_little_endian:
             a = a.byteswap()
         assert len(a) == self.bin_size
@@ -275,13 +272,13 @@ class FileBinnedArray(object):
             return self.get(key)
 
 
-class BinnedArrayWriter(object):
+class BinnedArrayWriter:
     def __init__(self, f, bin_size=512*1024, default=NaN, max_size=MAX, typecode="f", comp_type='zlib'):
         # All parameters in the constructor are immutable after creation
         self.f = f
         self.max_size = max_size
         self.bin_size = bin_size
-        self.nbins = int(math.ceil((max_size / self.bin_size)))
+        self.nbins = int(math.ceil(max_size / self.bin_size))
         self.default = default
         self.typecode = typecode
         self.bin = 0
@@ -310,7 +307,7 @@ class BinnedArrayWriter(object):
         # around that by byteswapping the array
         if platform_is_little_endian:
             a = a.byteswap()
-        self.f.write(a.tostring())
+        self.f.write(a.tobytes())
         # Save current position (start of bin offsets)
         self.index_pos = self.f.tell()
         self.data_offset = self.index_pos + (self.nbins * calcsize(">2I"))
@@ -347,9 +344,9 @@ class BinnedArrayWriter(object):
         if self.buffer_contains_values:
             pos = self.f.tell()
             if platform_is_little_endian:
-                s = self.buffer.byteswap().tostring()
+                s = self.buffer.byteswap().tobytes()
             else:
-                s = self.buffer.tostring()
+                s = self.buffer.tobytes()
             compressed = self.compress(s)
             size = len(compressed)
             assert len(self.bin_index) == self.bin
