@@ -8,7 +8,6 @@ formats.
 
 For gff/gtf, the start_codon stop_codon line types are merged with CDSs.
 """
-from __future__ import print_function
 
 import sys
 
@@ -25,7 +24,7 @@ def GeneReader(fh, format='gff'):
 
     known_formats = ('gff', 'gtf', 'bed')
     if format not in known_formats:
-        print('%s format not in %s' % (format, ",".join(known_formats)), file=sys.stderr)
+        print('{} format not in {}'.format(format, ",".join(known_formats)), file=sys.stderr)
         raise Exception('?')
 
     if format == 'bed':
@@ -89,7 +88,7 @@ def CDSReader(fh, format='gff'):
 
     known_formats = ('gff', 'gtf', 'bed')
     if format not in known_formats:
-        print('%s format not in %s' % (format, ",".join(known_formats)), file=sys.stderr)
+        print('{} format not in {}'.format(format, ",".join(known_formats)), file=sys.stderr)
         raise Exception('?')
 
     if format == 'bed':
@@ -151,7 +150,7 @@ def CDSReader(fh, format='gff'):
         # for gene in genelist.values():
         for gene in grouplist:
             chrom, strand, cds_exons = genelist[gene]
-            seqlen = sum([a[1]-a[0] for a in cds_exons])
+            seqlen = sum(a[1]-a[0] for a in cds_exons)
             overhang = seqlen % 3
             if overhang > 0:
                 if strand == '+':
@@ -175,7 +174,7 @@ def FeatureReader(fh, format='gff', alt_introns_subtract="exons", gtf_parse=None
 
     known_formats = ('gff', 'gtf', 'bed')
     if format not in known_formats:
-        print('%s format not in %s' % (format, ",".join(known_formats)), file=sys.stderr)
+        print('{} format not in {}'.format(format, ",".join(known_formats)), file=sys.stderr)
         raise Exception('?')
 
     if format == 'bed':
@@ -289,7 +288,7 @@ def FeatureReader(fh, format='gff', alt_introns_subtract="exons", gtf_parse=None
                 introns = bitset_union(introns)
 
             # assure CDS is a multiple of 3, trim from last exon if necessary
-            seqlen = sum([a[1]-a[0] for a in cds_exons])
+            seqlen = sum(a[1]-a[0] for a in cds_exons)
             overhang = seqlen % 3
             if overhang > 0:
                 if strand == '+':
