@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import os
 import sys
 import unittest
@@ -203,7 +201,7 @@ class IntervalTreeTest(unittest.TestCase):
     def test_public_interval(self):
 
         def fn(ival):
-            return self.assert_(ival.interval)
+            return self.assertTrue(ival.interval)
 
         self.iv.traverse(fn)
 
