@@ -40,7 +40,7 @@ def usage(s=None):
     if s is None:
         sys.exit(message)
     else:
-        sys.exit("%s\n%s" % (s, message))
+        sys.exit(f"{s}\n{message}")
 
 
 def main():
@@ -133,7 +133,7 @@ def parse_spec(spec):  # returns (seq_file,species_name,lengths_file)
 def read_lengths(fileName):
     chromToLength = {}
 
-    f = open(fileName, "r")
+    f = open(fileName)
 
     for lineNumber, line in enumerate(f):
         line = line.strip()
