@@ -1,12 +1,10 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 """
 For each interval in `bed1` count the number of intersecting regions in `bed2`.
 
 usage: %prog bed1 bed2
 """
 
-from __future__ import print_function
-
 import sys
 
 from bx.intervals import (
