@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 
 """
 Match up intersecting intervals from two files. This performs a "full join",
@@ -6,7 +6,6 @@ any pair of intervals with any basewise overlap will be printed side-by-side.
 
 usage: %prog bed1 bed2
 """
-from __future__ import division, print_function
 
 import sys
 
