@@ -12,12 +12,11 @@ usage: %prog maf_file index_file
 import os.path
 from io import TextIOWrapper
 
-from six import PY3
-
 import bx.align.maf
 from bx import interval_index_file
 from bx.cookbook import doc_optparse
 from bx.misc.seekbzip2 import SeekableBzip2File
+from bx.misc.seeklzop import SeekableLzopFile
 
 
 def main():
@@ -36,7 +35,6 @@ def main():
             # Strip .bz2 from the filename before adding ".index"
             maf_file = maf_file[:-4]
         elif maf_file.endswith(".lzo"):
-            from bx.misc.seeklzop import SeekableLzopFile
             table_file = maf_file + "t"
             if not os.path.exists(table_file):
                 doc_optparse.exit("To index lzo compressed files first "
@@ -59,9 +57,8 @@ def main():
     except Exception:
         doc_optparse.exception()
 
-    if PY3:
-        maf_in = TextIOWrapper(maf_in, encoding="ascii")
-    maf_reader = bx.align.maf.Reader(maf_in)
+    maf_in = TextIOWrapper(maf_in, encoding="ascii")
+    maf_reader = bx.align.maf.Reader(maf_in, parse_e_rows=True)
 
     indexes = interval_index_file.Indexes()
 
