@@ -1,9 +1,8 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 usage: %prog species1,species2,... nrequired < maf
 """
-from __future__ import print_function
 
 import sys
 
