@@ -1,11 +1,10 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 """
 Create a bed file listing all the divergent sites between two specific species
 in a maf.
 
 usage: %prog maf_file reference_species_name other_species_name
 """
-from __future__ import print_function
 
 import sys
 
