@@ -9,6 +9,9 @@ NOTE: See maf_extract_ranges_indexed.py which works better / faster for many
 
 NOTE: chromosome/src information in the MAF is ignored by this variant.
 
+NOTE: if a single alignment in a block become empty during slicing, the block
+      is ignored.
+
 usage: %prog interval_file refindex [options] < maf_file
    -m, --mincols=10: Minimum length (columns) required for alignment to be output
 """
@@ -49,7 +52,7 @@ def __main__():
 
     # Iterate over input MAF
 
-    for maf in bx.align.maf.Reader(sys.stdin):
+    for maf in bx.align.maf.Reader(sys.stdin, parse_e_rows=True):
         ref = maf.components[refindex]
         # Find overlap with reference component
         intersections = sorted(intersecter.find(ref.get_forward_strand_start(), ref.get_forward_strand_end()))
@@ -61,7 +64,7 @@ def __main__():
             sliced = maf.slice_by_component(refindex, start, end)
             good = True
             for c in sliced.components:
-                if c.size < 1:
+                if c.size < 1 and not c.empty:
                     good = False
             if good and sliced.text_size > mincols:
                 out.write(sliced)
