@@ -37,7 +37,7 @@ def __main__():
     if expr:
         expr = compile(expr, '<expr arg>', 'eval')
 
-    maf_reader = maf.Reader(sys.stdin)
+    maf_reader = maf.Reader(sys.stdin, parse_e_rows=True)
     maf_writer = maf.Writer(sys.stdout)
 
     for m in maf_reader:
