@@ -1,11 +1,10 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 Read a MAF from standard input and print average GC content of each alignment
 
 usage: %prog < maf > out
 """
-from __future__ import division, print_function
 
 import sys
 
