@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 
 """
 WARNING: bz2/bz2t support and file cache support are new and not as well
@@ -9,7 +9,6 @@ usage: %prog maf_files [options] < interval_file
     -p, --prefix=PREFIX: Prefix to add to each interval chrom (usually reference species)
    -C, --usecache:   Use a cache that keeps blocks of the MAF files in memory (requires ~20MB per MAF)
 """
-from __future__ import division, print_function
 
 import sys
 
