@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 Read a MAF from standard input and determine the mean length of ungapped pieces
@@ -6,7 +6,6 @@ in each block.
 
 usage: %prog < maf > out
 """
-from __future__ import division, print_function
 
 import sys
 
