@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 Read a PAIRWISE maf from stdin and print the percent identity of each
@@ -9,7 +9,6 @@ TODO: Generalize for more than two species
 
 usage: %prog < maf > out
 """
-from __future__ import division, print_function
 
 import sys
 
