@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 Read a maf from stdin and print the chromosome number for each alignment. It
@@ -10,7 +10,6 @@ NOTE: See 'align_print_template.py' for a more general variation of this
 
 usage: %prog refindex [options]
 """
-from __future__ import division, print_function
 
 import sys
 
