@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python
 
 """
 Takes a list of maf filenames on the command line and prints a comma separated
@@ -6,12 +6,9 @@ list of the species that occur in all of the mafs.
 
 usage %prog maf1 maf2 ...
 """
-from __future__ import print_function
-
 import operator
 import sys
-
-from six.moves import reduce
+from functools import reduce
 
 import bx.align.maf
 
