@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.3
+#!/usr/bin/env python
 
 """
 Read a MAF and print counts and frequencies of all n-mers
@@ -8,7 +8,6 @@ TODO: reconcile this and maf_mapping_word_frequency.py
 
 usage: %prog n < maf_file
 """
-from __future__ import division, print_function
 
 import string
 import sys
